@@ -16,7 +16,8 @@
 """Adders that use Reverb (github.com/deepmind/reverb) as a backend."""
 
 import abc
-from typing import Callable, Iterable, Mapping, NamedTuple, Optional, Union, Tuple
+import time
+from typing import Callable, Iterable, Mapping, NamedTuple, Optional, Sized, Union, Tuple
 
 from absl import logging
 from acme import specs
@@ -29,6 +30,7 @@ import tensorflow as tf
 import tree
 
 DEFAULT_PRIORITY_TABLE = 'priority_table'
+_MIN_WRITER_LIFESPAN_SECONDS = 60
 StartOfEpisodeType = Union[bool, specs.Array, tf.Tensor, tf.TensorSpec,
                            Tuple[()]]
 
@@ -105,6 +107,7 @@ class ReverbAdder(base.Adder):
     self._priority_fns = priority_fns
     self._max_sequence_length = max_sequence_length
     self._delta_encoded = delta_encoded
+    # TODO(b/206629159): Remove this.
     self._max_in_flight_items = max_in_flight_items
     self._add_first_called = False
 
@@ -122,7 +125,7 @@ class ReverbAdder(base.Adder):
       timeout_ms = 10_000
       # Try flush all appended data before closing to avoid loss of experience.
       try:
-        self.__writer.flush(self._max_in_flight_items, timeout_ms=timeout_ms)
+        self.__writer.flush(0, timeout_ms=timeout_ms)
       except reverb.DeadlineExceededError as e:
         logging.error(
             'Timeout (%d ms) exceeded when flushing the writer before '
@@ -135,6 +138,7 @@ class ReverbAdder(base.Adder):
       self.__writer = self._client.trajectory_writer(
           num_keep_alive_refs=self._max_sequence_length,
           get_signature_timeout_ms=self._get_signature_timeout_ms)
+      self._writer_created_timestamp = time.time()
     return self.__writer
 
   def add_priority_table(self, table_name: str,
@@ -151,6 +155,12 @@ class ReverbAdder(base.Adder):
     if self.__writer:
       # Flush all appended data and clear the buffers.
       self.__writer.end_episode(clear_buffers=True, timeout_ms=timeout_ms)
+
+      # Create a new writer unless the current one is too young.
+      # This is to reduce the relative overhead of creating a new Reverb writer.
+      if (time.time() - self._writer_created_timestamp >
+          _MIN_WRITER_LIFESPAN_SECONDS):
+        self.__writer = None
     self._add_first_called = False
 
   def add_first(self, timestep: dm_env.TimeStep):
@@ -176,13 +186,15 @@ class ReverbAdder(base.Adder):
       raise ValueError('adder.add_first must be called before adder.add.')
 
     # Add the timestep to the buffer.
+    has_extras = (len(extras) > 0 if isinstance(extras, Sized)  # pylint: disable=g-explicit-length-test
+                  else extras is not None)
     current_step = dict(
         # Observation was passed at the previous add call.
         action=action,
         reward=next_timestep.reward,
         discount=next_timestep.discount,
         # Start of episode indicator was passed at the previous add call.
-        **({'extras': extras} if extras else {})
+        **({'extras': extras} if has_extras else {})
     )
     self._writer.append(current_step)
 
