@@ -55,7 +55,7 @@ def make_networks(
       ])
     return network(obs)
 
-  policy = hk.without_apply_rng(hk.transform(_actor_fn, apply_rng=True))
+  policy = hk.without_apply_rng(hk.transform(_actor_fn))
 
   # Create dummy observations and actions to create network parameters.
   dummy_obs = utils.zeros_like(spec.observations)
@@ -74,6 +74,7 @@ class BCTest(parameterized.TestCase):
       )
   def test_continuous_actions(self, loss_name):
     with chex.fake_pmap_and_jit():
+      num_sgd_steps_per_step = 1
       num_steps = 5
 
       # Create a fake environment to test with.
@@ -102,18 +103,17 @@ class BCTest(parameterized.TestCase):
       else:
         raise ValueError
 
-      learner_core = bc.make_bc_learner_core(
+      learner = bc.BCLearner(
           network=network,
+          random_key=jax.random.PRNGKey(0),
           loss_fn=loss_fn,
-          optimizer=optax.adam(0.01))
-
-      step_fn = jax.jit(learner_core.step)
-
-      state = learner_core.init(jax.random.PRNGKey(0))
+          optimizer=optax.adam(0.01),
+          demonstrations=dataset_demonstration,
+          num_sgd_steps_per_step=num_sgd_steps_per_step)
 
       # Train the agent
       for _ in range(num_steps):
-        state = step_fn(state, next(dataset_demonstration)).state
+        learner.step()
 
   @parameterized.parameters(
       ('logp',),
@@ -121,6 +121,7 @@ class BCTest(parameterized.TestCase):
   def test_discrete_actions(self, loss_name):
     with chex.fake_pmap_and_jit():
 
+      num_sgd_steps_per_step = 1
       num_steps = 5
 
       # Create a fake environment to test with.
@@ -156,18 +157,17 @@ class BCTest(parameterized.TestCase):
       else:
         raise ValueError
 
-      learner_core = bc.make_bc_learner_core(
+      learner = bc.BCLearner(
           network=network,
+          random_key=jax.random.PRNGKey(0),
           loss_fn=loss_fn,
-          optimizer=optax.adam(0.01))
-
-      step_fn = jax.jit(learner_core.step)
-
-      state = learner_core.init(jax.random.PRNGKey(0))
+          optimizer=optax.adam(0.01),
+          demonstrations=dataset_demonstration,
+          num_sgd_steps_per_step=num_sgd_steps_per_step)
 
       # Train the agent
       for _ in range(num_steps):
-        state = step_fn(state, next(dataset_demonstration)).state
+        learner.step()
 
 
 if __name__ == '__main__':
