@@ -15,8 +15,12 @@
 
 """Implementation of a deep Q-networks (DQN) agent."""
 
+from acme.agents.jax.dqn.actor import behavior_policy
+from acme.agents.jax.dqn.actor import default_behavior_policy
 from acme.agents.jax.dqn.agent import DQN
-from acme.agents.jax.dqn.builder import default_behavior_policy
 from acme.agents.jax.dqn.builder import DQNBuilder
 from acme.agents.jax.dqn.config import DQNConfig
 from acme.agents.jax.dqn.learning import DQNLearner
+from acme.agents.jax.dqn.learning_lib import SGDLearner
+from acme.agents.jax.dqn.losses import PrioritizedDoubleQLearning
+from acme.agents.jax.dqn.losses import QrDqn
