@@ -15,12 +15,16 @@
 
 """DQN agent implementation."""
 
+from typing import Sequence
+
 from acme import specs
 from acme.agents import agent
 from acme.agents import replay
+from acme.agents.jax import actor_core as actor_core_lib
 from acme.agents.jax import actors
 from acme.agents.jax.dqn import config as dqn_config
-from acme.agents.jax.dqn import learning
+from acme.agents.jax.dqn import learning_lib
+from acme.agents.jax.dqn import losses
 from acme.jax import networks as networks_lib
 from acme.jax import variable_utils
 import jax
@@ -63,27 +67,30 @@ class DQNFromConfig(agent.Agent):
     )
     key_learner, key_actor = jax.random.split(jax.random.PRNGKey(config.seed))
     # The learner updates the parameters (and initializes them).
-    learner = learning.DQNLearner(
-        network=network,
-        random_key=key_learner,
-        optimizer=optimizer,
+    loss_fn = losses.PrioritizedDoubleQLearning(
         discount=config.discount,
         importance_sampling_exponent=config.importance_sampling_exponent,
+    )
+    learner = learning_lib.SGDLearner(
+        network=network,
+        loss_fn=loss_fn,
+        data_iterator=reverb_replay.data_iterator,
+        optimizer=optimizer,
         target_update_period=config.target_update_period,
-        iterator=reverb_replay.data_iterator,
+        random_key=key_learner,
         replay_client=reverb_replay.client,
     )
 
     # The actor selects actions according to the policy.
+    assert config.epsilon is not Sequence
     def policy(params: networks_lib.Params, key: jnp.ndarray,
                observation: jnp.ndarray) -> jnp.ndarray:
       action_values = network.apply(params, observation)
       return rlax.epsilon_greedy(config.epsilon).sample(key, action_values)
-    actor = actors.FeedForwardActor(
-        policy=policy,
-        random_key=key_actor,
-        variable_client=variable_utils.VariableClient(learner, ''),
-        adder=reverb_replay.adder)
+    actor_core = actor_core_lib.batched_feed_forward_to_actor_core(policy)
+    variable_client = variable_utils.VariableClient(learner, '')
+    actor = actors.GenericActor(
+        actor_core, key_actor, variable_client, reverb_replay.adder)
 
     super().__init__(
         actor=actor,
