@@ -13,7 +13,7 @@
 # limitations under the License.
 
 """DQN Builder."""
-from typing import Callable, Iterator, List, Optional
+from typing import Callable, Iterator, List, Optional, Sequence
 
 from acme import adders
 from acme import core
@@ -21,6 +21,7 @@ from acme import specs
 from acme.adders import reverb as adders_reverb
 from acme.agents.jax import actors
 from acme.agents.jax import builders
+from acme.agents.jax.dqn import actor as dqn_actor
 from acme.agents.jax.dqn import config as dqn_config
 from acme.agents.jax.dqn import learning_lib
 from acme.datasets import reverb as datasets
@@ -28,22 +29,9 @@ from acme.jax import networks as networks_lib
 from acme.jax import variable_utils
 from acme.utils import counting
 from acme.utils import loggers
-import jax.numpy as jnp
 import optax
 import reverb
 from reverb import rate_limiters
-import rlax
-
-
-def default_behavior_policy(network: networks_lib.FeedForwardNetwork,
-                            epsilon: float,
-                            params: networks_lib.Params,
-                            key: networks_lib.PRNGKey,
-                            observation: networks_lib.Observation):
-  """Returns an action for the given observation."""
-  action_values = network.apply(params, observation)
-  actions = rlax.epsilon_greedy(epsilon).sample(key, action_values)
-  return actions.astype(jnp.int32)
 
 
 class DQNBuilder(builders.ActorLearnerBuilder):
@@ -54,17 +42,20 @@ class DQNBuilder(builders.ActorLearnerBuilder):
       config: dqn_config.DQNConfig,
       loss_fn: learning_lib.LossFn,
       logger_fn: Callable[[], loggers.Logger] = lambda: None,
+      actor_backend: Optional[str] = 'cpu'
   ):
     """Creates DQN learner and the behavior policies.
 
     Args:
       config: DQN config.
       loss_fn: A loss function.
-      logger_fn: a logger factory for the learner
+      logger_fn: a logger factory for the learner.
+      actor_backend: Which backend to use when jitting the policy.
     """
     self._config = config
     self._loss_fn = loss_fn
     self._logger_fn = logger_fn
+    self._actor_backend = actor_backend
 
   def make_learner(
       self,
@@ -73,16 +64,17 @@ class DQNBuilder(builders.ActorLearnerBuilder):
       dataset: Iterator[reverb.ReplaySample],
       replay_client: Optional[reverb.Client] = None,
       counter: Optional[counting.Counter] = None,
-      checkpoint: bool = False,
   ) -> core.Learner:
     return learning_lib.SGDLearner(
         network=networks,
         random_key=random_key,
-        optimizer=optax.adam(self._config.learning_rate),
+        optimizer=optax.adam(self._config.learning_rate,
+                             eps=self._config.adam_eps),
         target_update_period=self._config.target_update_period,
         data_iterator=dataset,
         loss_fn=self._loss_fn,
-        replay_client=None,
+        replay_client=replay_client,
+        replay_table_name=self._config.replay_table_name,
         counter=counter,
         num_sgd_steps_per_step=self._config.num_sgd_steps_per_step,
         logger=self._logger_fn())
@@ -90,19 +82,23 @@ class DQNBuilder(builders.ActorLearnerBuilder):
   def make_actor(
       self,
       random_key: networks_lib.PRNGKey,
-      policy_network,
+      policy_network: dqn_actor.EpsilonPolicy,
       adder: Optional[adders.Adder] = None,
       variable_source: Optional[core.VariableSource] = None,
   ) -> core.Actor:
     assert variable_source is not None
-    return actors.FeedForwardActor(
-        policy=policy_network,
-        random_key=random_key,
-        # Inference happens on CPU, so it's better to move variables there too.
-        variable_client=variable_utils.VariableClient(
-            variable_source, '', device='cpu'),
-        adder=adder,
-    )
+    # Inference happens on CPU, so it's better to move variables there too.
+    variable_client = variable_utils.VariableClient(variable_source, '',
+                                                    device='cpu')
+    epsilon = self._config.epsilon
+    epsilons = epsilon if epsilon is Sequence else (epsilon,)
+    actor_core = dqn_actor.alternating_epsilons_actor_core(
+        policy_network, epsilons=epsilons)
+    return actors.GenericActor(actor=actor_core,
+                               random_key=random_key,
+                               variable_client=variable_client,
+                               adder=adder,
+                               backend=self._actor_backend)
 
   def make_replay_tables(
       self, environment_spec: specs.EnvironmentSpec) -> List[reverb.Table]:
