@@ -18,4 +18,8 @@
 
 from acme.agents.jax.impala.agent import IMPALA
 from acme.agents.jax.impala.agent import IMPALAFromConfig
+from acme.agents.jax.impala.config import IMPALAConfig
 from acme.agents.jax.impala.learning import IMPALALearner
+from acme.agents.jax.impala.networks import IMPALANetworks
+from acme.agents.jax.impala.networks import make_atari_networks
+from acme.agents.jax.impala.networks import make_haiku_networks
