@@ -15,7 +15,6 @@
 
 """Importance weighted advantage actor-critic (IMPALA) agent implementation."""
 
-import dataclasses
 from typing import Callable, Optional, Union
 
 import acme
@@ -23,9 +22,11 @@ from acme import specs
 from acme import types
 from acme.agents import replay
 from acme.agents.jax.impala import acting
+from acme.agents.jax.impala import config as impala_config
 from acme.agents.jax.impala import learning
+from acme.agents.jax.impala import networks as impala_networks
 from acme.agents.jax.impala import types as impala_types
-from acme.jax import networks
+from acme.jax import networks as networks_lib
 from acme.jax import variable_utils
 from acme.utils import counting
 from acme.utils import loggers
@@ -36,34 +37,6 @@ import numpy as np
 import optax
 
 
-@dataclasses.dataclass
-class IMPALAConfig:
-  """Configuration options for IMPALA."""
-  seed: int = 0
-
-  # Loss options
-  batch_size: int = 16
-  sequence_length: int = 20
-  sequence_period: int = 20
-  discount: float = 0.99
-  entropy_cost: float = 0.01
-  baseline_cost: float = 0.5
-  max_abs_reward: float = np.inf
-  max_gradient_norm: float = np.inf
-
-  # Optimizer options
-  learning_rate: float = 1e-4
-  adam_momentum_decay: float = 0.0
-  adam_variance_decay: float = 0.99
-
-  # Replay options
-  max_queue_size: Union[int, types.Batches] = types.Batches(10)
-
-  def __post_init__(self):
-    if isinstance(self.max_queue_size, types.Batches):
-      self.max_queue_size *= self.batch_size
-
-
 class IMPALAFromConfig(acme.Actor):
   """IMPALA Agent."""
 
@@ -75,10 +48,17 @@ class IMPALAFromConfig(acme.Actor):
       unroll_fn: impala_types.PolicyValueFn,
       initial_state_init_fn: impala_types.RecurrentStateInitFn,
       initial_state_fn: impala_types.RecurrentStateFn,
-      config: IMPALAConfig,
+      config: impala_config.IMPALAConfig,
       counter: Optional[counting.Counter] = None,
       logger: Optional[loggers.Logger] = None,
   ):
+    networks = impala_networks.IMPALANetworks(
+        forward_fn=forward_fn,
+        unroll_init_fn=unroll_init_fn,
+        unroll_fn=unroll_fn,
+        initial_state_init_fn=initial_state_init_fn,
+        initial_state_fn=initial_state_fn,
+    )
 
     self._config = config
 
@@ -112,11 +92,7 @@ class IMPALAFromConfig(acme.Actor):
     )
     key_learner, key_actor = jax.random.split(key)
     self._learner = learning.IMPALALearner(
-        obs_spec=environment_spec.observations,
-        unroll_init_fn=unroll_init_fn,
-        unroll_fn=unroll_fn,
-        initial_state_init_fn=initial_state_init_fn,
-        initial_state_fn=initial_state_fn,
+        networks=networks,
         iterator=reverb_queue.data_iterator,
         random_key=key_learner,
         counter=counter,
@@ -173,8 +149,8 @@ class IMPALA(IMPALAFromConfig):
   def __init__(
       self,
       environment_spec: specs.EnvironmentSpec,
-      forward_fn: networks.PolicyValueRNN,
-      unroll_fn: networks.PolicyValueRNN,
+      forward_fn: networks_lib.PolicyValueRNN,
+      unroll_fn: networks_lib.PolicyValueRNN,
       initial_state_fn: Callable[[], hk.LSTMState],
       sequence_length: int,
       sequence_period: int,
@@ -183,25 +159,19 @@ class IMPALA(IMPALAFromConfig):
       discount: float = 0.99,
       max_queue_size: Union[int, types.Batches] = types.Batches(10),
       batch_size: int = 16,
-      learning_rate: float = 1e-3,
+      learning_rate: float = 1e-4,
       entropy_cost: float = 0.01,
       baseline_cost: float = 0.5,
       seed: int = 0,
       max_abs_reward: float = np.inf,
       max_gradient_norm: float = np.inf,
   ):
+    networks = impala_networks.make_haiku_networks(
+        env_spec=environment_spec,
+        forward_fn=forward_fn, initial_state_fn=initial_state_fn,
+        unroll_fn=unroll_fn)
 
-    forward_fn_transformed = hk.without_apply_rng(hk.transform(
-        forward_fn,
-        apply_rng=True))
-    unroll_fn_transformed = hk.without_apply_rng(hk.transform(
-        unroll_fn,
-        apply_rng=True))
-    initial_state_fn_transformed = hk.without_apply_rng(hk.transform(
-        initial_state_fn,
-        apply_rng=True))
-
-    config = IMPALAConfig(
+    config = impala_config.IMPALAConfig(
         sequence_length=sequence_length,
         sequence_period=sequence_period,
         discount=discount,
@@ -214,13 +184,14 @@ class IMPALA(IMPALAFromConfig):
         max_abs_reward=max_abs_reward,
         max_gradient_norm=max_gradient_norm,
     )
+
     super().__init__(
         environment_spec=environment_spec,
-        forward_fn=forward_fn_transformed.apply,
-        unroll_init_fn=unroll_fn_transformed.init,
-        unroll_fn=unroll_fn_transformed.apply,
-        initial_state_init_fn=initial_state_fn_transformed.init,
-        initial_state_fn=initial_state_fn_transformed.apply,
+        forward_fn=networks.forward_fn,
+        unroll_init_fn=networks.unroll_init_fn,
+        unroll_fn=networks.unroll_fn,
+        initial_state_init_fn=networks.initial_state_init_fn,
+        initial_state_fn=networks.initial_state_fn,
         config=config,
         counter=counter,
         logger=logger,
