@@ -14,19 +14,20 @@
 # limitations under the License.
 
 """Some types/assumptions used in the IMPALA agent."""
-from typing import Callable
+from typing import Callable, Tuple
 
+from acme.agents.jax.actor_core import RecurrentState
 from acme.jax import networks
-import haiku as hk
 import jax.numpy as jnp
 
 
 # Only simple observations & discrete action spaces for now.
 Observation = jnp.ndarray
 Action = int
-PolicyValueInitFn = Callable[[networks.PRNGKey, Observation, hk.LSTMState],
+Outputs = Tuple[Tuple[networks.Logits, networks.Value], RecurrentState]
+PolicyValueInitFn = Callable[[networks.PRNGKey, RecurrentState],
                              networks.Params]
-PolicyValueFn = Callable[[networks.Params, Observation, hk.LSTMState],
-                         networks.LSTMOutputs]
+PolicyValueFn = Callable[[networks.Params, Observation, RecurrentState],
+                         Outputs]
 RecurrentStateInitFn = Callable[[networks.PRNGKey], networks.Params]
-RecurrentStateFn = Callable[[networks.Params], hk.LSTMState]
+RecurrentStateFn = Callable[[networks.Params], RecurrentState]
