@@ -39,7 +39,7 @@ class Actor(abc.ABC):
 
     # Make the first observation.
     timestep = env.reset()
-    actor.observe_first(timestep.observation)
+    actor.observe_first(timestep)
 
     # Take a step and observe.
     action = actor.select_action(timestep.observation)
@@ -108,6 +108,8 @@ class VariableSource(abc.ABC):
       corresponds to the collection named by `names[i]`.
     """
 
+# Placeholder for an Actor alias
+
 
 @metrics.record_class_usage
 class Worker(abc.ABC):
