@@ -17,11 +17,13 @@
 
 import operator
 import time
-from typing import Optional
+from typing import Optional, Sequence
 
 from acme import core
 from acme.utils import counting
 from acme.utils import loggers
+from acme.utils import observers as observers_lib
+from acme.utils import signals
 
 import dm_env
 from dm_env import specs
@@ -47,6 +49,10 @@ class EnvironmentLoop(core.Worker):
   by utils.loggers.make_default_logger. A string `label` can be passed to easily
   change the label associated with the default logger; this is ignored if a
   `Logger` instance is given.
+
+  A list of 'Observer' instances can be specified to generate additional metrics
+  to be logged by the logger. They have access to the 'Environment' instance,
+  the current timestep datastruct and the current action.
   """
 
   def __init__(
@@ -57,6 +63,7 @@ class EnvironmentLoop(core.Worker):
       logger: Optional[loggers.Logger] = None,
       should_update: bool = True,
       label: str = 'environment_loop',
+      observers: Sequence[observers_lib.EnvLoopObserver] = (),
   ):
     # Internalize agent and environment.
     self._environment = environment
@@ -64,6 +71,7 @@ class EnvironmentLoop(core.Worker):
     self._counter = counter or counting.Counter()
     self._logger = logger or loggers.make_default_logger(label)
     self._should_update = should_update
+    self._observers = observers
 
   def run_episode(self) -> loggers.LoggingData:
     """Run one episode.
@@ -84,9 +92,12 @@ class EnvironmentLoop(core.Worker):
     episode_return = tree.map_structure(_generate_zeros_from_spec,
                                         self._environment.reward_spec())
     timestep = self._environment.reset()
-
     # Make the first observation.
     self._actor.observe_first(timestep)
+    for observer in self._observers:
+      # Initialize the observer with the current state of the env after reset
+      # and the initial timestep.
+      observer.observe_first(self._environment, timestep)
 
     # Run an episode.
     while not timestep.last():
@@ -96,6 +107,10 @@ class EnvironmentLoop(core.Worker):
 
       # Have the agent observe the timestep and let the actor update itself.
       self._actor.observe(action, next_timestep=timestep)
+      for observer in self._observers:
+        # One environment step was completed. Observe the current state of the
+        # environment, the current timestep and the action.
+        observer.observe(self._environment, timestep, action)
       if self._should_update:
         self._actor.update()
 
@@ -122,6 +137,8 @@ class EnvironmentLoop(core.Worker):
         'steps_per_second': steps_per_second,
     }
     result.update(counts)
+    for observer in self._observers:
+      result.update(observer.get_metrics())
     return result
 
   def run(self,
@@ -154,12 +171,15 @@ class EnvironmentLoop(core.Worker):
               (num_steps is not None and step_count >= num_steps))
 
     episode_count, step_count = 0, 0
-    while not should_terminate(episode_count, step_count):
-      result = self.run_episode()
-      episode_count += 1
-      step_count += result['episode_length']
-      # Log the given results.
-      self._logger.write(result)
+    with signals.runtime_terminator():
+      while not should_terminate(episode_count, step_count):
+        result = self.run_episode()
+        episode_count += 1
+        step_count += result['episode_length']
+        # Log the given episode results.
+        self._logger.write(result)
+
+# Placeholder for an EnvironmentLoop alias
 
 
 def _generate_zeros_from_spec(spec: specs.Array) -> np.ndarray:
