@@ -61,6 +61,7 @@ class GaussianMixture(hk.Module):
                multivariate: bool,
                init_scale: Optional[float] = None,
                append_singleton_event_dim: bool = False,
+               reinterpreted_batch_ndims: Optional[int] = None,
                name: str = 'GaussianMixture'):
     """Initialization.
 
@@ -71,6 +72,8 @@ class GaussianMixture(hk.Module):
       init_scale: the initial scale for the Gaussian mixture components.
       append_singleton_event_dim: (univariate only) Whether to add an extra
         singleton dimension to the event shape.
+      reinterpreted_batch_ndims: (univariate only) Number of batch dimensions to
+        reinterpret as event dimensions.
       name: name of the module passed to snt.Module parent class.
     """
     super().__init__(name=name)
@@ -79,6 +82,7 @@ class GaussianMixture(hk.Module):
     self._num_components = num_components
     self._multivariate = multivariate
     self._append_singleton_event_dim = append_singleton_event_dim
+    self._reinterpreted_batch_ndims = reinterpreted_batch_ndims
 
     if init_scale is not None:
       self._scale_factor = init_scale / jax.nn.softplus(0.)
@@ -150,7 +154,9 @@ class GaussianMixture(hk.Module):
         components_distribution=components_class(loc=locs, scale=scales))
 
     if not self._multivariate:
-      distribution = tfd.Independent(distribution)
+      distribution = tfd.Independent(
+          distribution,
+          reinterpreted_batch_ndims=self._reinterpreted_batch_ndims)
 
     return distribution
 
@@ -199,6 +205,19 @@ class TanhTransformedDistribution(tfd.TransformedDistribution):
   def mode(self):
     return self.bijector.forward(self.distribution.mode())
 
+  def entropy(self, seed=None):
+    # We return an estimation using a single sample of the log_det_jacobian.
+    # We can still do some backpropagation with this estimate.
+    return self.distribution.entropy() + self.bijector.forward_log_det_jacobian(
+        self.distribution.sample(seed=seed), event_ndims=0)
+
+  @classmethod
+  def _parameter_properties(cls, dtype: Optional[Any], num_classes=None):
+    td_properties = super()._parameter_properties(dtype,
+                                                  num_classes=num_classes)
+    del td_properties['bijector']
+    return td_properties
+
 
 class NormalTanhDistribution(hk.Module):
   """Module that produces a TanhTransformedDistribution distribution."""
@@ -236,6 +255,7 @@ class MultivariateNormalDiagHead(hk.Module):
 
   def __init__(self,
                num_dimensions: int,
+               init_scale: float = 0.3,
                min_scale: float = 1e-6,
                w_init: hk_init.Initializer = hk_init.VarianceScaling(1e-4),
                b_init: hk_init.Initializer = hk_init.Constant(0.)):
@@ -243,19 +263,22 @@ class MultivariateNormalDiagHead(hk.Module):
 
     Args:
       num_dimensions: Number of dimensions of MVN distribution.
+      init_scale: Initial standard deviation.
       min_scale: Minimum standard deviation.
       w_init: Initialization for linear layer weights.
       b_init: Initialization for linear layer biases.
     """
     super().__init__(name='MultivariateNormalDiagHead')
     self._min_scale = min_scale
+    self._init_scale = init_scale
     self._loc_layer = hk.Linear(num_dimensions, w_init=w_init, b_init=b_init)
     self._scale_layer = hk.Linear(num_dimensions, w_init=w_init, b_init=b_init)
 
   def __call__(self, inputs: jnp.ndarray) -> tfd.Distribution:
     loc = self._loc_layer(inputs)
-    scale = self._scale_layer(inputs)
-    scale = jax.nn.softplus(scale) + self._min_scale
+    scale = jax.nn.softplus(self._scale_layer(inputs))
+    scale *= self._init_scale / jax.nn.softplus(0.)
+    scale += self._min_scale
     return tfd.MultivariateNormalDiag(loc=loc, scale_diag=scale)
 
 
