@@ -23,7 +23,7 @@ from typing import Callable, Generator, Iterable, NamedTuple, Optional, Sequence
 
 from absl import logging
 from acme import types
-from acme.jax.types import TrainingMetrics, TrainingStepOutput  # pylint: disable=g-multiple-import
+from acme.jax.types import PRNGKey, TrainingMetrics, TrainingStepOutput  # pylint: disable=g-multiple-import
 import jax
 import jax.numpy as jnp
 import numpy as np
@@ -274,7 +274,7 @@ def replicate_in_all_devices(nest: N,
                             ) -> N:
   """Replicate array nest in all available devices."""
   devices = devices or jax.local_devices()
-  return jax.api.device_put_sharded([nest] * len(devices), devices)
+  return jax.device_put_sharded([nest] * len(devices), devices)
 
 
 def get_from_first_device(nest: N, as_numpy: bool = True) -> N:
@@ -292,14 +292,15 @@ def get_from_first_device(nest: N, as_numpy: bool = True) -> N:
     array will be copied to the host machine and converted into a `np.ndarray`.
   """
 
-  def _slice_and_maybe_to_numpy(x):
+  def _check_type_and_slice(x):
     if not isinstance(x, jax.pxla.ShardedDeviceArray):
       raise ValueError('get_from_first_device should only be used with '
                        f'{jax.pxla.ShardedDeviceArray}, passed {type(x)}.')
-    x = x[0]
-    return _fetch_devicearray(x) if as_numpy else x
+    return x[0]
 
-  return jax.tree_map(_slice_and_maybe_to_numpy, nest)
+  zeroth_nest = jax.tree_map(_check_type_and_slice, nest)
+
+  return jax.device_get(zeroth_nest) if as_numpy else zeroth_nest
 
 
 def mapreduce(
@@ -416,3 +417,12 @@ def weighted_softmax(x: jnp.ndarray, weights: jnp.ndarray, axis: int = 0):
   x = x - jnp.max(x, axis=axis)
   return weights * jnp.exp(x) / jnp.sum(weights * jnp.exp(x),
                                         axis=axis, keepdims=True)
+
+
+def sample_uint32(random_key: PRNGKey) -> int:
+  """Returns an integer uniformly distributed in 0..2^32-1."""
+  iinfo = jnp.iinfo(jnp.int32)
+  # randint only accepts int32 values as min and max.
+  jax_random = jax.random.randint(
+      random_key, shape=(), minval=iinfo.min, maxval=iinfo.max, dtype=jnp.int32)
+  return np.uint32(jax_random).item()
