@@ -19,14 +19,13 @@ import abc
 import datetime
 import os
 import pickle
-import signal
 import time
 from typing import Mapping, Optional, Union
 
 from absl import logging
 from acme import core
-from acme.utils import paths
 from acme.utils import signals
+from acme.utils import paths
 import sonnet as snt
 import tensorflow as tf
 import tensorflow_probability as tfp
@@ -183,6 +182,7 @@ class CheckpointingRunner(core.Worker):
   def __init__(
       self,
       wrapped: Union[Checkpointable, core.Saveable, TFSaveable],
+      key: str = 'wrapped',
       *,
       time_delta_minutes: int = 30,
       **kwargs,
@@ -198,16 +198,14 @@ class CheckpointingRunner(core.Worker):
     self._wrapped = wrapped
     self._time_delta_minutes = time_delta_minutes
     self._checkpointer = Checkpointer(
-        objects_to_save={'wrapped': objects_to_save},
+        objects_to_save={key: objects_to_save},
         time_delta_minutes=time_delta_minutes,
         **kwargs)
 
-    # Handle preemption signal. Note that this must happen in the main thread.
-    def _signal_handler():
-      logging.info('Caught SIGTERM: forcing a checkpoint save.')
-      self._checkpointer.save(force=True)
-
-    signals.add_handler(signal.SIGTERM, _signal_handler)
+  # Handle preemption signal. Note that this must happen in the main thread.
+  def _signal_handler(self):
+    logging.info('Caught SIGTERM: forcing a checkpoint save.')
+    self._checkpointer.save(force=True)
 
   def step(self):
     if isinstance(self._wrapped, core.Learner):
@@ -220,8 +218,9 @@ class CheckpointingRunner(core.Worker):
 
   def run(self):
     """Runs the checkpointer."""
-    while True:
-      self.step()
+    with signals.runtime_terminator(self._signal_handler):
+      while True:
+        self.step()
 
   def __dir__(self):
     return dir(self._wrapped) + ['get_directory']
@@ -234,7 +233,10 @@ class CheckpointingRunner(core.Worker):
 
   def checkpoint(self):
     self._checkpointer.save()
-    time.sleep(self._time_delta_minutes * 60)
+    # Do not sleep for a long period of time to avoid LaunchPad program
+    # termination hangs (time.sleep is not interruptible).
+    for _ in range(self._time_delta_minutes * 60):
+      time.sleep(1)
 
   def get_directory(self):
     return self._checkpointer.directory
